@@ -15,13 +15,15 @@
 # limitations under the License.
 
 import os
+import urllib
 
 import optparse
+from oslo_config import cfg
 from oslo_serialization import jsonutils
-import urllib2
+
+from networking_bagpipe.bagpipe_bgp.api import config as api_config
 
 
-BAGPIPE_PORT = 8082
 LOOKING_GLASS_BASE = "looking-glass"
 
 
@@ -31,11 +33,11 @@ def request(options, server, args):
     try:
         os.environ['NO_PROXY'] = server
         os.environ['no_proxy'] = server
-        response = urllib2.urlopen(target_url)
+        response = urllib.request.urlopen(target_url)
 
         if response.getcode() == 200:
             return jsonutils.load(response)
-    except urllib2.HTTPError as e:
+    except urllib.error.HTTPError as e:
         if e.code == 404:
             return {}
         print("Error requesting %s" % target_url)
@@ -52,6 +54,7 @@ def normalize(string):
             .replace("-", "_")
             .replace(".", "_"))
 
+
 RT_TXT_STYLE = 'color="orange",fontcolor="orange"'
 RT_STYLE = 'color="orange",fontcolor="orange",arrowhead=onormal'
 RT_STYLE_REDIR_FROM_RT = ('color="orange",fontcolor="orange",style=dashed,'
@@ -109,6 +112,15 @@ def vpn_short(vpn):
 
 
 def main():
+    api_config.register_config()
+    try:
+        cfg.CONF(args=[],
+                 project='bagpipe-impex2dot',
+                 default_config_files=['/etc/bagpipe-bgp/bgp.conf'])
+        api_port = cfg.CONF.API.port
+    except cfg.ConfigFilesNotFoundError:
+        api_port = api_config.DEFAULT_PORT
+
     usage = """ %prog [options]
 
 Example: bagpipe-impex2dot --server s1 --server s2 | dot -Tpdf > impex.pdf
@@ -120,7 +132,7 @@ Example: bagpipe-impex2dot --server s1 --server s2 | dot -Tpdf > impex.pdf
         help="IP address of a BaGPipe BGP instances (default: localhost)")
 
     parser.add_option(
-        "--port", dest="port", type="int", default=BAGPIPE_PORT,
+        "--port", dest="port", type="int", default=api_port,
         help="Port of BaGPipe BGP (optional, default: %default)")
 
     parser.add_option(
